import { select } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;
  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'lightgreen');

  //STEMS
  svg.selectAll('rect.stem')
    .data([1, 2, 3, 4, 5]) 
    .enter().append('rect')
    .attr('class', 'stem')
    .attr('x', (d, i) => i * 100 + 245) 
    .attr('y', height / 2.5)
    .attr('width', 10)
    .attr('height', 100)
    .attr('fill', 'green');

  // FLOWER
  const petalColors = ['red', 'pink', 'orange', 'blue', 'purple'];
  const growthDuration = 2000; 

  petalColors.forEach((color, index) => {
    const flowerX = index * 100 + 250; 
    const flowerY = height / 2 - 50; 
    const petalSize = 20;

    // PETALS
    for (let j = 0; j < 8; j++) {
      const angle = Math.PI * 2 / 8 * j;
      const petalX = flowerX + Math.cos(angle) * petalSize;
      const petalY = flowerY + Math.sin(angle) * petalSize;

      svg.append('circle')
        .attr('cx', petalX)
        .attr('cy', petalY)
        .attr('r', 0) 
        .attr('fill', color)
        .transition() 
        .duration(growthDuration)
        .attr('r', petalSize / 2);
    }

    // CENTER
    svg.append('circle')
      .attr('cx', flowerX)
      .attr('cy', flowerY)
      .attr('r', 0) 
      .attr('fill', 'yellow')
      .transition() 
      .duration(growthDuration)
      .attr('r', petalSize / 2);

    // LEAVES
  const leafWidth = 15;
  const leafHeight = 8;
  const stemSpacing = 100; 
  
  for (let i = 0; i < 5; i++) {
    const stemX = i * stemSpacing + 245;
    
    // Leaf path
    svg.append('path')
      .attr('d', `M${stemX},${height / 2.5 + 50} 
                  q${-leafWidth / 2},${-leafHeight / 2} 
                  ${-leafWidth / 2},${leafHeight} 
                  q${leafWidth / 2},${leafHeight / 2} 
                  ${leafWidth / 2},${-leafHeight}`)
      .attr('fill', 'green');
    
    // Right leaf
    svg.append('path')
      .attr('d', `M${stemX+10},${height / 2.5 + 50} 
                  q${leafWidth / 2},${-leafHeight / 2} 
                    ${leafWidth / 2},${leafHeight} 
                  q${-leafWidth / 2},${leafHeight / 2} 
                  ${-leafWidth / 2},${-leafHeight}`)
      .attr('fill', 'green');
  }
  
  });
};
